@@ -3,8 +3,8 @@ import concurrent.futures
 import copy
 import itertools
 import os
-import platform
 import string
+import sys
 import tempfile
 import time
 import typing
@@ -58,6 +58,9 @@ TEMPLATE_URL = "https://gitlab.com/gitlab-org/gitlab/-/raw/master/lib/gitlab/ci/
 # Global variables
 __version__ = "1.1"
 
+# Force output to utf-8
+sys.stdout.reconfigure(encoding="utf-8")
+
 
 class GitlabCI:
     # pylint: disable=too-few-public-methods
@@ -383,7 +386,7 @@ class GitlabJob:
                                                  working_dir=variables['CI_PROJECT_DIR'],
                                                  )
         for line in container.logs(stream=True):
-            print(line.decode('utf-8'), end="", flush=True)
+            print(line.decode("utf-8"), end="", flush=True)
 
         result = container.wait()['StatusCode']
         container.remove()
